@@ -1,8 +1,9 @@
 # -*- coding: utf-8 -*
 from .lca import LCA
+from .least_squares import LeastSquaresLCA
 from .monte_carlo import MonteCarloLCA, ParallelMonteCarlo, MultiMonteCarlo
 from .mc_vector import ParameterVectorLCA
 from .graph_traversal import GraphTraversal
 from .matrices import MatrixBuilder, TechnosphereBiosphereMatrixBuilder
 
-__version__ = (0, 15)
+__version__ = (0, 15, 1)
