@@ -96,9 +96,9 @@ class ComparativeMonteCarlo(IterativeMonteCarlo):
     def load_data(self):
         self.load_lci_data()
         self.load_lcia_data()
-        self.tech_rng = MCRandomNumberGenerator(self.tech_params, seed=seed)
-        self.bio_rng = MCRandomNumberGenerator(self.bio_params, seed=seed)
-        self.cf_rng = MCRandomNumberGenerator(self.cf_params, seed=seed)
+        self.tech_rng = MCRandomNumberGenerator(self.tech_params, seed=self.seed)
+        self.bio_rng = MCRandomNumberGenerator(self.bio_params, seed=self.seed)
+        self.cf_rng = MCRandomNumberGenerator(self.cf_params, seed=self.seed)
 
     def next(self):
         self.rebuild_technosphere_matrix(self.tech_rng.next())
@@ -127,18 +127,20 @@ class ParallelMonteCarlo(object):
                  cpus=None):
         self.demand = demand
         self.method = method
+        self.cpus = cpus
         if chunk_size:
             self.chunk_size = chunk_size
             self.num_jobs = iterations // chunk_size
             if iterations % self.chunk_size:
                 self.num_jobs += 1
         else:
-            self.num_jobs = cpus or multiprocessing.cpu_count()
+            self.num_jobs = self.cpus or multiprocessing.cpu_count()
             self.chunk_size = (iterations // self.num_jobs) + 1
 
     def calculate(self, worker=single_worker):
-        pool = multiprocessing.Pool(processes=max(
-            multiprocessing.cpu_count() - 1, 1))
+        pool = multiprocessing.Pool(
+            processes=min(self.num_jobs, multiprocessing.cpu_count())
+        )
         results = [pool.apply_async(worker, (self.demand, self.method,
                    self.chunk_size)) for x in xrange(self.num_jobs)]
         pool.close()
